# `potamides` library

```{toctree}
:maxdepth: 1
:caption: API submodules
:glob:

splinelib.md

```

---

```{eval-rst}

.. currentmodule:: potamides

.. automodule:: potamides
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: aval, default, materialise, enable_materialise

```
